@@ -5,7 +5,7 @@
 source_suffix = '.rst'
 master_doc = 'index'
 
-copyright = u'2019 Damien Goutte-Gattat'
+copyright = u'2019–2021 Damien Goutte-Gattat'
 author = u'Damien Goutte-Gattat <dgouttegattat@incenp.org>'
 
 language = 'en'
@@ -17,13 +17,11 @@ pygments_style = 'sphinx'
 extensions = ['sphinx.ext.intersphinx']
 intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}
 
-
 # -- Options for HTML output ----------------------------------------------
 
-html_theme = 'alabaster'
+html_theme = 'sphinx_rtd_theme'
 html_static_path = ['_static']
 
-
 # -- Options for LaTeX output ---------------------------------------------
 
 latex_engine = 'lualatex'
@@ -41,7 +39,6 @@ latex_documents = [
      u'Damien Goutte-Gattat', 'manual'),
 ]
 
-
 # -- Options for manual page output ---------------------------------------
 
 man_pages = [
@@ -49,7 +46,6 @@ man_pages = [
      [author], 1)
 ]
 
-
 # -- Options for Texinfo output -------------------------------------------
 
 texinfo_documents = [
